{
    "$graph": [
        {
            "class": "Workflow",
            "label": "SV filtering workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#labelled_file.yml/labelled_file",
                            "label": "a file with a label",
                            "fields": [
                                {
                                    "type": "File",
                                    "name": "#labelled_file.yml/labelled_file/file"
                                },
                                {
                                    "type": "string",
                                    "name": "#labelled_file.yml/labelled_file/label"
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "id": "#main/maximum_sv_population_frequency"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/sv_intervals"
                },
                {
                    "type": "File",
                    "id": "#main/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#filter_vcf_max_sv_pop_freq.cwl",
                    "in": [
                        {
                            "source": "#main/maximum_sv_population_frequency",
                            "id": "#main/filter_sv_pop/maximum_sv_population_frequency"
                        },
                        {
                            "source": "#main/vcf",
                            "id": "#main/filter_sv_pop/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_sv_pop/filtered_vcf"
                    ],
                    "id": "#main/filter_sv_pop"
                },
                {
                    "run": "#bedtools_intersect.cwl",
                    "scatter": [
                        "#main/intersect_variants/file_b",
                        "#main/intersect_variants/output_name"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/filter_sv_pop/filtered_vcf",
                            "id": "#main/intersect_variants/file_a"
                        },
                        {
                            "source": "#main/interval_to_bed/interval_bed",
                            "id": "#main/intersect_variants/file_b"
                        },
                        {
                            "source": "#main/sv_intervals",
                            "valueFrom": "intersect-$(self.label).vcf",
                            "id": "#main/intersect_variants/output_name"
                        }
                    ],
                    "out": [
                        "#main/intersect_variants/intersect_result"
                    ],
                    "id": "#main/intersect_variants"
                },
                {
                    "run": "#intervals_to_bed.cwl",
                    "scatter": [
                        "#main/interval_to_bed/interval_list"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/sv_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#main/interval_to_bed/interval_list"
                        }
                    ],
                    "out": [
                        "#main/interval_to_bed/interval_bed"
                    ],
                    "id": "#main/interval_to_bed"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/intersect_variants/intersect_result",
                    "id": "#main/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/filter_sv_pop/filtered_vcf",
                    "id": "#main/sv_pop_filtered_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/opt/ccdg/bedtools-2.27.1/bin/bedtools",
                "intersect"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ernfrid/bedtools:v2.27.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.output_name)",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-a"
                    },
                    "doc": "BAM/BED/GFF/VCF file to compare to file b",
                    "id": "#bedtools_intersect.cwl/file_a"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-b"
                    },
                    "doc": "BAM/BED/GFF/VCF file to compare to file a",
                    "id": "#bedtools_intersect.cwl/file_b"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-wa"
                    },
                    "doc": "Write the original entry in A for each overlap, default to true",
                    "id": "#bedtools_intersect.cwl/output_file_a"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-header"
                    },
                    "doc": "Print the header from the A file prior to results, default to true",
                    "id": "#bedtools_intersect.cwl/output_header"
                },
                {
                    "type": "string",
                    "id": "#bedtools_intersect.cwl/output_name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-u"
                    },
                    "doc": "Write original A entry once if any overlaps found in B, default to true",
                    "id": "#bedtools_intersect.cwl/unique_result"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bedtools_intersect.cwl/intersect_result",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    }
                }
            ],
            "id": "#bedtools_intersect.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "POPFREQ_AF filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:1.0.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.max_sv_pf_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/src/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "--vcf_info_field",
                "tmp",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.max_sv_pf_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "inputBinding": {
                        "valueFrom": "${\n    return [\n        \"--filter\",\n        [\n            \"POPFREQ_AF\", \"<\", inputs.maximum_sv_population_frequency,\n            \"or not\", \"POPFREQ_AF\"\n        ].join(\" \")\n    ]\n}\n",
                        "position": 2
                    },
                    "id": "#filter_vcf_max_sv_pop_freq.cwl/maximum_sv_population_frequency"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#filter_vcf_max_sv_pop_freq.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.max_sv_pf_filtered.vcf"
                    },
                    "id": "#filter_vcf_max_sv_pop_freq.cwl/filtered_vcf"
                }
            ],
            "id": "#filter_vcf_max_sv_pop_freq.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/intervals_to_bed.pl"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/perl_helper-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "interval_list.bed",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#intervals_to_bed.cwl/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#intervals_to_bed.cwl/interval_bed",
                    "outputBinding": {
                        "glob": "interval_list.bed"
                    }
                }
            ],
            "id": "#intervals_to_bed.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
